@@ -2,7 +2,7 @@
 """
 
 # Force __all__ modules to be imported when importing sysmpy package
-from sysmpy import *
+# from sysmpy import *
 
 # in __init__.py
 from sysmpy.entity import *
