@@ -1,5 +1,5 @@
 import asyncio
-from relationship import *
+from sysmpy.relationship import *
 import random
 import queue
 import traceback
